VCL Packet
Defines VCLPacket — the core unit of data transmission in VCL Protocol —
and PacketType which determines how the connection layer routes each packet.
Every packet is:
- Chained — contains the SHA-256 hash of the previous packet in the same direction
- Signed — Ed25519 signature over the packet hash
- Encrypted — payload encrypted with XChaCha20-Poly1305
Structs
- VCLPacket
- A single unit of data transmission in VCL Protocol.
Enums
- Packet
Type - Determines how a
VCLPacketis routed by the connection layer.